@@ -3,10 +3,14 @@ use std::path::PathBuf;
 
 use pico_args::Arguments;
 
+use crate::info::{DESC, NAME, VERSION};
+
 pub struct Cli {
     // Print help information
     pub help: bool,
 
+    pub version: bool,
+
     // Whether to substitute variables or not
     pub expand: bool,
 
@@ -42,6 +46,7 @@ impl Cli {
         let mut bin_args = bin_args.into_iter();
         let res = Cli {
             help: args.contains(["-h", "--help"]),
+            version: args.contains(["-v", "--version"]),
             expand: args.contains(["-x", "--expand"]),
             path: args
                 .opt_value_from_str(["-f", "--file"])
@@ -59,11 +64,48 @@ impl Cli {
         Ok(res)
     }
 
-    pub fn path(&self) -> Result<&PathBuf, &str> {
-        self.path.as_ref().ok_or("-f/--file option is required")
+    pub fn path(&self) -> Result<&PathBuf, String> {
+        let p = self.path.as_ref().ok_or("-f/--file option is required")?;
+
+        match p.exists() {
+            true => Ok(p),
+            false => Err(format!("Unable to find file - `{}`", p.display())),
+        }
     }
 
     pub fn binary(&self) -> Result<&OsString, &str> {
         self.binary.as_ref().ok_or("<binary> name is required")
     }
+
+    pub fn help_doc() -> String {
+        format!(
+            "\
+{name} {ver}
+{desc}
+
+USAGE:
+    {name} [FLAGS] [OPTIONS] -- <binary> [args]...
+
+FLAGS:
+    -v, --version       Prints version
+    -h, --help          Prints help information
+    -x, --expand        Enable variable expansion
+
+OPTIONS:
+    -f, --file          Path to .env file
+
+ARGS:
+    <binary>            Command that needs to be executed
+    [args]...           Arguments for the command
+
+Examples:
+    {name} -f .env -- node index.js
+    {name} -f .env -- npm run dev
+    {name} -f .env -- terraform apply
+",
+            name = NAME,
+            ver = VERSION,
+            desc = DESC,
+        )
+    }
 }
